summaryrefslogtreecommitdiffstats
path: root/kutils
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2012-06-08 15:51:46 -0500
committerDarrell Anderson <humanreadable@yahoo.com>2012-06-08 15:51:46 -0500
commit6ed1ea98db6b1b369e7561efcc2c666b810e5446 (patch)
tree69da6d265387965c04a9584547ec42d4d372717d /kutils
parent09d01cacf80d21ad213e6520b35e7f06e9546a83 (diff)
downloadtdelibs-6ed1ea98db6b1b369e7561efcc2c666b810e5446.tar.gz
tdelibs-6ed1ea98db6b1b369e7561efcc2c666b810e5446.zip
Update XDG information in support of bug report 892.
Diffstat (limited to 'kutils')
-rw-r--r--kutils/kcmoduleinfo.cpp12
-rw-r--r--kutils/kcmoduleinfo.h2
-rw-r--r--kutils/kcmoduleloader.cpp2
-rw-r--r--kutils/kcmoduleloader.h2
-rw-r--r--kutils/kcmultidialog.cpp2
-rw-r--r--kutils/kplugininfo.cpp38
-rw-r--r--kutils/kplugininfo.desktop20
-rw-r--r--kutils/kplugininfo.h22
-rw-r--r--kutils/kpluginselector.cpp2
-rw-r--r--kutils/ksettings/README.dox74
-rw-r--r--kutils/ksettings/dialog.cpp8
-rw-r--r--kutils/ksettings/dialog.h4
-rw-r--r--kutils/ksettings/dispatcher.h4
-rw-r--r--kutils/ksettings/pluginpage.h10
14 files changed, 101 insertions, 101 deletions
diff --git a/kutils/kcmoduleinfo.cpp b/kutils/kcmoduleinfo.cpp
index bb27f5c69..c34069c09 100644
--- a/kutils/kcmoduleinfo.cpp
+++ b/kutils/kcmoduleinfo.cpp
@@ -96,7 +96,7 @@ TQString KCModuleInfo::factoryName() const
{
if( d->factoryName.isEmpty() )
{
- d->factoryName = _service->property("X-KDE-FactoryName", TQVariant::String).toString();
+ d->factoryName = _service->property("X-TDE-FactoryName", TQVariant::String).toString();
if ( d->factoryName.isEmpty() )
d->factoryName = library();
}
@@ -155,27 +155,27 @@ KCModuleInfo::loadAll()
_allLoaded = true;
// library and factory
- setHandle(_service->property("X-KDE-FactoryName", TQVariant::String).toString());
+ setHandle(_service->property("X-TDE-FactoryName", TQVariant::String).toString());
TQVariant tmp;
// read weight
- tmp = _service->property( "X-KDE-Weight", TQVariant::Int );
+ tmp = _service->property( "X-TDE-Weight", TQVariant::Int );
setWeight( tmp.isValid() ? tmp.toInt() : 100 );
// does the module need super user privileges?
- tmp = _service->property( "X-KDE-RootOnly", TQVariant::Bool );
+ tmp = _service->property( "X-TDE-RootOnly", TQVariant::Bool );
setNeedsRootPrivileges( tmp.isValid() ? tmp.toBool() : false );
// does the module need to be shown to root only?
// Deprecated ! KDE 4
- tmp = _service->property( "X-KDE-IsHiddenByDefault", TQVariant::Bool );
+ tmp = _service->property( "X-TDE-IsHiddenByDefault", TQVariant::Bool );
setIsHiddenByDefault( tmp.isValid() ? tmp.toBool() : false );
// get the documentation path
setDocPath( _service->property( "DocPath", TQVariant::String ).toString() );
- tmp = _service->property( "X-KDE-Test-Module", TQVariant::Bool );
+ tmp = _service->property( "X-TDE-Test-Module", TQVariant::Bool );
setNeedsTest( tmp.isValid() ? tmp.asBool() : false );
}
diff --git a/kutils/kcmoduleinfo.h b/kutils/kcmoduleinfo.h
index 49a66a952..b2e79ee46 100644
--- a/kutils/kcmoduleinfo.h
+++ b/kutils/kcmoduleinfo.h
@@ -163,7 +163,7 @@ public:
/**
* @return the weight of the module which determines the order of the pages in
- * the KCMultiDialog. It's set by the X-KDE-Weight field.
+ * the KCMultiDialog. It's set by the X-TDE-Weight field.
*/
int weight() const;
diff --git a/kutils/kcmoduleloader.cpp b/kutils/kcmoduleloader.cpp
index 99d2f88a2..c8327a25e 100644
--- a/kutils/kcmoduleloader.cpp
+++ b/kutils/kcmoduleloader.cpp
@@ -240,7 +240,7 @@ bool KCModuleLoader::testModule( const KCModuleInfo& module )
return true;
}
- bool doLoad = module.service()->property( "X-KDE-Test-Module", TQVariant::Bool ).toBool();
+ bool doLoad = module.service()->property( "X-TDE-Test-Module", TQVariant::Bool ).toBool();
if( !doLoad )
{
return true;
diff --git a/kutils/kcmoduleloader.h b/kutils/kcmoduleloader.h
index 34435d6d8..9e0871241 100644
--- a/kutils/kcmoduleloader.h
+++ b/kutils/kcmoduleloader.h
@@ -156,7 +156,7 @@ class KUTILS_EXPORT KCModuleLoader
* be made available, leaving the decision to the user.
* If false is returned, the module should not be loaded in any interface.
*
- * A module declares it needs to be tested by having "X-KDE-Test-Module=true" in
+ * A module declares it needs to be tested by having "X-TDE-Test-Module=true" in
* its desktop file. When that line exists, the following code must be available
* in the module's library:
*
diff --git a/kutils/kcmultidialog.cpp b/kutils/kcmultidialog.cpp
index 768f787fe..53934349e 100644
--- a/kutils/kcmultidialog.cpp
+++ b/kutils/kcmultidialog.cpp
@@ -296,7 +296,7 @@ void KCMultiDialog::addModule(const KCModuleInfo& moduleinfo,
{
module = new KCModuleProxy( moduleinfo, withfallback, page );
TQStringList parentComponents = moduleinfo.service()->property(
- "X-KDE-ParentComponents" ).toStringList();
+ "X-TDE-ParentComponents" ).toStringList();
moduleParentComponents.insert( module,
new TQStringList( parentComponents ) );
diff --git a/kutils/kplugininfo.cpp b/kutils/kplugininfo.cpp
index a441fb756..7b83be7ed 100644
--- a/kutils/kplugininfo.cpp
+++ b/kutils/kplugininfo.cpp
@@ -84,16 +84,16 @@ KPluginInfo::KPluginInfo( const TQString & filename, const char* resource )
d->name = file.readName();
d->comment = file.readComment();
d->icon = file.readEntry( "Icon" );
- d->author = file.readEntry( "X-KDE-PluginInfo-Author" );
- d->email = file.readEntry( "X-KDE-PluginInfo-Email" );
- d->pluginName = file.readEntry( "X-KDE-PluginInfo-Name" );
- d->version = file.readEntry( "X-KDE-PluginInfo-Version" );
- d->website = file.readEntry( "X-KDE-PluginInfo-Website" );
- d->category = file.readEntry( "X-KDE-PluginInfo-Category" );
- d->license = file.readEntry( "X-KDE-PluginInfo-License" );
- d->dependencies = file.readListEntry( "X-KDE-PluginInfo-Depends" );
+ d->author = file.readEntry( "X-TDE-PluginInfo-Author" );
+ d->email = file.readEntry( "X-TDE-PluginInfo-Email" );
+ d->pluginName = file.readEntry( "X-TDE-PluginInfo-Name" );
+ d->version = file.readEntry( "X-TDE-PluginInfo-Version" );
+ d->website = file.readEntry( "X-TDE-PluginInfo-Website" );
+ d->category = file.readEntry( "X-TDE-PluginInfo-Category" );
+ d->license = file.readEntry( "X-TDE-PluginInfo-License" );
+ d->dependencies = file.readListEntry( "X-TDE-PluginInfo-Depends" );
d->enabledbydefault = file.readBoolEntry(
- "X-KDE-PluginInfo-EnabledByDefault", false );
+ "X-TDE-PluginInfo-EnabledByDefault", false );
}
else if( filename.endsWith( TQString::fromAscii( ".plugin" ) ) )
{ // provided for noatun style .plugin files compatibility
@@ -127,16 +127,16 @@ KPluginInfo::KPluginInfo( const KService::Ptr service )
d->name = service->name();
d->comment = service->comment();
d->icon = service->icon();
- d->author = service->property( "X-KDE-PluginInfo-Author" ).toString();
- d->email = service->property( "X-KDE-PluginInfo-Email" ).toString();
- d->pluginName = service->property( "X-KDE-PluginInfo-Name" ).toString();
- d->version = service->property( "X-KDE-PluginInfo-Version" ).toString();
- d->website = service->property( "X-KDE-PluginInfo-Website" ).toString();
- d->category = service->property( "X-KDE-PluginInfo-Category" ).toString();
- d->license = service->property( "X-KDE-PluginInfo-License" ).toString();
+ d->author = service->property( "X-TDE-PluginInfo-Author" ).toString();
+ d->email = service->property( "X-TDE-PluginInfo-Email" ).toString();
+ d->pluginName = service->property( "X-TDE-PluginInfo-Name" ).toString();
+ d->version = service->property( "X-TDE-PluginInfo-Version" ).toString();
+ d->website = service->property( "X-TDE-PluginInfo-Website" ).toString();
+ d->category = service->property( "X-TDE-PluginInfo-Category" ).toString();
+ d->license = service->property( "X-TDE-PluginInfo-License" ).toString();
d->dependencies =
- service->property( "X-KDE-PluginInfo-Depends" ).toStringList();
- TQVariant tmp = service->property( "X-KDE-PluginInfo-EnabledByDefault" );
+ service->property( "X-TDE-PluginInfo-Depends" ).toStringList();
+ TQVariant tmp = service->property( "X-TDE-PluginInfo-EnabledByDefault" );
d->enabledbydefault = tmp.isValid() ? tmp.toBool() : false;
}
@@ -277,7 +277,7 @@ const TQValueList<KService::Ptr> & KPluginInfo::kcmServices() const
if ( !d->kcmservicesCached )
{
d->kcmservices = KTrader::self()->query( "KCModule", "'" + d->pluginName +
- "' in [X-KDE-ParentComponents]" );
+ "' in [X-TDE-ParentComponents]" );
kdDebug( 703 ) << "found " << d->kcmservices.count() << " offers for " <<
d->pluginName << endl;
diff --git a/kutils/kplugininfo.desktop b/kutils/kplugininfo.desktop
index 07a15e1c5..d88712b9d 100644
--- a/kutils/kplugininfo.desktop
+++ b/kutils/kplugininfo.desktop
@@ -1,6 +1,6 @@
[Desktop Entry]
Type=ServiceType
-X-KDE-ServiceType=KPluginInfo
+X-TDE-ServiceType=KPluginInfo
Name=TDE Plugin Information
Name[af]=TDE Inprop module Informasie
Name[ar]=معلومات ملحقات كيدي
@@ -79,29 +79,29 @@ Name[zh_CN]=TDE 打印信息
Name[zh_HK]=TDE 外掛資訊
Name[zh_TW]=TDE 外掛資訊
-[PropertyDef::X-KDE-PluginInfo-Author]
+[PropertyDef::X-TDE-PluginInfo-Author]
Type=TQString
-[PropertyDef::X-KDE-PluginInfo-Email]
+[PropertyDef::X-TDE-PluginInfo-Email]
Type=TQString
-[PropertyDef::X-KDE-PluginInfo-Name]
+[PropertyDef::X-TDE-PluginInfo-Name]
Type=TQString
-[PropertyDef::X-KDE-PluginInfo-Version]
+[PropertyDef::X-TDE-PluginInfo-Version]
Type=TQString
-[PropertyDef::X-KDE-PluginInfo-Website]
+[PropertyDef::X-TDE-PluginInfo-Website]
Type=TQString
-[PropertyDef::X-KDE-PluginInfo-Category]
+[PropertyDef::X-TDE-PluginInfo-Category]
Type=TQString
-[PropertyDef::X-KDE-PluginInfo-Depends]
+[PropertyDef::X-TDE-PluginInfo-Depends]
Type=TQStringList
-[PropertyDef::X-KDE-PluginInfo-License]
+[PropertyDef::X-TDE-PluginInfo-License]
Type=TQString
-[PropertyDef::X-KDE-PluginInfo-EnabledByDefault]
+[PropertyDef::X-TDE-PluginInfo-EnabledByDefault]
Type=bool
diff --git a/kutils/kpluginselector.cpp b/kutils/kpluginselector.cpp
index 99b88efd9..a385d2719 100644
--- a/kutils/kpluginselector.cpp
+++ b/kutils/kpluginselector.cpp
@@ -254,7 +254,7 @@ TQWidget * KPluginSelectionWidget::insertKCM( TQWidget * parent,
d->modulelist.append( module );
TQStringList * parentComponents = new TQStringList(
moduleinfo.service()->property(
- "X-KDE-ParentComponents" ).toStringList() );
+ "X-TDE-ParentComponents" ).toStringList() );
d->moduleParentComponents.insert( module, parentComponents );
connect( module, TQT_SIGNAL( changed( bool ) ), TQT_SLOT( clientChanged( bool ) ) );
return module;
diff --git a/kutils/ksettings/README.dox b/kutils/ksettings/README.dox
index 0660324c1..4abfc6be5 100644
--- a/kutils/ksettings/README.dox
+++ b/kutils/ksettings/README.dox
@@ -28,7 +28,7 @@ m_dlg->show();
Of course you need to have the 'KSettings::Dialog * m_dlg' member var and
initialize it to 0 in the ctor.
-If your application uses KParts that don't set 'X-KDE-ParentApp=&lt;the instance
+If your application uses KParts that don't set 'X-TDE-ParentApp=&lt;the instance
name of your application&gt;' then you need to use the second ctor of
KSettings::Dialog:
\code
@@ -96,12 +96,12 @@ Icon=myapp
Type=Service
ServiceTypes=KCModule
-X-KDE-ModuleType=Library
-X-KDE-Library=myappconfig
-X-KDE-FactoryName=MyAppConfigFactory
-X-KDE-ParentApp=myapp
-X-KDE-ParentComponents=myapp
-X-KDE-Weight=10
+X-TDE-ModuleType=Library
+X-TDE-Library=myappconfig
+X-TDE-FactoryName=MyAppConfigFactory
+X-TDE-ParentApp=myapp
+X-TDE-ParentComponents=myapp
+X-TDE-Weight=10
Name=General
Comment=General configuration of my app
@@ -109,23 +109,23 @@ Comment=General configuration of my app
Some explanation for those keys:
-- You just keep 'Encoding', 'Type', 'ServiceTypes' and 'X-KDE-ModuleType' like
+- You just keep 'Encoding', 'Type', 'ServiceTypes' and 'X-TDE-ModuleType' like
in the example. For very special needs you might add another ServiceType to
the list...
- Icon is the icon that will be used in the listview/iconview for your page.
-- X-KDE-Library is the name of the library where the page is in. The library
+- X-TDE-Library is the name of the library where the page is in. The library
always needs to be prefixed with kcm_ but you don't write the prefix in the
desktop file. For more docu on this look for the KCModule docu.
-- X-KDE-FactoryName is either the name of the Factory you used in the
+- X-TDE-FactoryName is either the name of the Factory you used in the
KGenericFactory call or the suffix of the create_ function that you created.
Again for more info look for the KCModule docu.
-- X-KDE-ParentApp is the name of the application this config page belongs to. It
+- X-TDE-ParentApp is the name of the application this config page belongs to. It
is used by the first two \ref KSettings::Dialog constructors. The Dialog will
- use all modules that set X-KDE-ParentApp to
+ use all modules that set X-TDE-ParentApp to
KGlobal::instance()->instanceName(). It
should be pretty easy to find out what name that is: look at the first
argument to the KAboutData ctor.
-- X-KDE-ParentComponents is a list of the components (plugin/KPart/whatever)
+- X-TDE-ParentComponents is a list of the components (plugin/KPart/whatever)
this config page belongs to. Normally there is only one component.
It is used for two things:
-# If you use KSettings::Dispatcher the dispatcher will notify all components
@@ -133,10 +133,10 @@ Some explanation for those keys:
components then can reload the configuration and apply the changes the user
did to the config.
-# If your component is used by another application (that is not =
- X-KDE-ParentApp) then it may add the name of the component to the ctor of
+ X-TDE-ParentApp) then it may add the name of the component to the ctor of
KSettings::Dialog and the dialog will automatically include all config
pages that have the components name in their ParentComponents list.
-- X-KDE-Weight sets the order for the modules to be inserted into the dialog.
+- X-TDE-Weight sets the order for the modules to be inserted into the dialog.
The higher the number (heavier) the lower the module will appear in the list.
(the default value is 100)
- Name is the string that is shown in the listview/iconview right below the
@@ -167,14 +167,14 @@ Parent=
\endverbatim
- The group name (id) is the name you use in the .desktop file of the page:
- If your page's .desktop file says "X-KDE-CfgDlgHierarchy=id" then it will be
+ If your page's .desktop file says "X-TDE-CfgDlgHierarchy=id" then it will be
inserted as a child of this entry.
- \p Name: The name of the section. It will appear in the listview.
- \p Comment: A description of what the modules in this section are. It will
appear in the place where the KCMs are placed when the user clicks on the item
in the listview.
- \p Icon: An icon for the item.
-- \p Weight: Defines the position in the listview. See X-KDE-Weight above.
+- \p Weight: Defines the position in the listview. See X-TDE-Weight above.
- \p Parent: If this group should be a child of another group write the parent's
group id here.
@@ -233,17 +233,17 @@ ServiceTypes=KPluginInfo
Name=MyPlugin
Comment=My plugin is cool and does foo and bar.
-X-KDE-PluginInfo-Name=myplugin
-
-X-KDE-PluginInfo-Author=<your name>
-X-KDE-PluginInfo-Email=<your email>
-X-KDE-PluginInfo-Website=http://www.myplugin.org/
-X-KDE-PluginInfo-Category=CoolPlugins
-X-KDE-PluginInfo-Version=0.1
-X-KDE-PluginInfo-License=GPL
-X-KDE-PluginInfo-EnabledByDefault=true
-X-KDE-PluginInfo-Depends=myotherplugin
-X-KDE-CfgDlgHierarchy=GroupID
+X-TDE-PluginInfo-Name=myplugin
+
+X-TDE-PluginInfo-Author=<your name>
+X-TDE-PluginInfo-Email=<your email>
+X-TDE-PluginInfo-Website=http://www.myplugin.org/
+X-TDE-PluginInfo-Category=CoolPlugins
+X-TDE-PluginInfo-Version=0.1
+X-TDE-PluginInfo-License=GPL
+X-TDE-PluginInfo-EnabledByDefault=true
+X-TDE-PluginInfo-Depends=myotherplugin
+X-TDE-CfgDlgHierarchy=GroupID
\endverbatim
Explanation:
@@ -251,23 +251,23 @@ mandatory entries:
- leave \p Type and \p Encoding like in the example
- \p Name
- \p Comment
-- \p X-KDE-PluginInfo-Name is the "internal name" of the plugin.
+- \p X-TDE-PluginInfo-Name is the "internal name" of the plugin.
- You need to have \p KPluginInfo in \p ServiceTypes but of course you may have more
entries in there.
optional entries:
- \p Icon is the icon used for your plugin (it's shown in the pluginselector if you
set one).
-- \p X-KDE-PluginInfo-Author and \p X-KDE-PluginInfo-Email is some information about the author of the plugin.
-- \p X-KDE-PluginInfo-Website is the address for a webpage for this plugin.
-- \p X-KDE-PluginInfo-Category is used if your application has different categories of plugins.
-- \p X-KDE-PluginInfo-Version is the version of this plugin.
-- \p X-KDE-PluginInfo-License is the license of this plugin.
-- \p X-KDE-PluginInfo-EnabledByDefault tells the program whether the plugin
+- \p X-TDE-PluginInfo-Author and \p X-TDE-PluginInfo-Email is some information about the author of the plugin.
+- \p X-TDE-PluginInfo-Website is the address for a webpage for this plugin.
+- \p X-TDE-PluginInfo-Category is used if your application has different categories of plugins.
+- \p X-TDE-PluginInfo-Version is the version of this plugin.
+- \p X-TDE-PluginInfo-License is the license of this plugin.
+- \p X-TDE-PluginInfo-EnabledByDefault tells the program whether the plugin
should be enabled on first startup or not.
-- \p X-KDE-PluginInfo-Depends can be used to tell the application that you need to have
+- \p X-TDE-PluginInfo-Depends can be used to tell the application that you need to have
myotherplugin enabled for your plugin to work.
-- \p X-KDE-CfgDlgHierarchy is used if you use a \p KSettings::Dialog::ConfigurableInline
+- \p X-TDE-CfgDlgHierarchy is used if you use a \p KSettings::Dialog::ConfigurableInline
KSettings::Dialog to put the plugin checkbox into the group with the GroupID
you set here.
diff --git a/kutils/ksettings/dialog.cpp b/kutils/ksettings/dialog.cpp
index 3ec83aeee..8fbe74c81 100644
--- a/kutils/ksettings/dialog.cpp
+++ b/kutils/ksettings/dialog.cpp
@@ -463,8 +463,8 @@ TQValueList<KService::Ptr> Dialog::parentComponentsServices(
{
d->registeredComponents += kcdparents;
TQString constraint = kcdparents.join(
- "' in [X-KDE-ParentComponents]) or ('" );
- constraint = "('" + constraint + "' in [X-KDE-ParentComponents])";
+ "' in [X-TDE-ParentComponents]) or ('" );
+ constraint = "('" + constraint + "' in [X-TDE-ParentComponents])";
kdDebug( 700 ) << "constraint = " << constraint << endl;
return KTrader::self()->query( "KCModule", constraint );
@@ -479,7 +479,7 @@ bool Dialog::isPluginForKCMEnabled( KCModuleInfo * moduleinfo ) const
<< " KCM should be shown" << endl;
// for all parent components
TQStringList parentComponents = moduleinfo->service()->property(
- "X-KDE-ParentComponents" ).toStringList();
+ "X-TDE-ParentComponents" ).toStringList();
for( TQStringList::ConstIterator pcit = parentComponents.begin();
pcit != parentComponents.end(); ++pcit )
{
@@ -550,7 +550,7 @@ void Dialog::createDialogFromServices()
// we create the KCModuleInfo
KCModuleInfo * info = new KCModuleInfo( *it );
TQString parentid;
- TQVariant tmp = info->service()->property( "X-KDE-CfgDlgHierarchy",
+ TQVariant tmp = info->service()->property( "X-TDE-CfgDlgHierarchy",
TQVariant::String );
if( tmp.isValid() )
parentid = tmp.toString();
diff --git a/kutils/ksettings/dialog.h b/kutils/ksettings/dialog.h
index 13f348287..5a8afa510 100644
--- a/kutils/ksettings/dialog.h
+++ b/kutils/ksettings/dialog.h
@@ -95,7 +95,7 @@ class KUTILS_EXPORT Dialog : public TQObject
/**
* Construct a new Preferences Dialog for the application. It uses all
- * KCMs with X-KDE-ParentApp set to KGlobal::instance()->instanceName().
+ * KCMs with X-TDE-ParentApp set to KGlobal::instance()->instanceName().
*
* @param parent The parent is only used as the parent for the
* dialog - centering the dialog over the parent
@@ -106,7 +106,7 @@ class KUTILS_EXPORT Dialog : public TQObject
/**
* Construct a new Preferences Dialog for the application. It uses all
- * KCMs with X-KDE-ParentApp set to KGlobal::instance()->instanceName().
+ * KCMs with X-TDE-ParentApp set to KGlobal::instance()->instanceName().
*
* @param content Select whether you want a static or configurable
* config dialog.
diff --git a/kutils/ksettings/dispatcher.h b/kutils/ksettings/dispatcher.h
index a35cfc142..52829f9e7 100644
--- a/kutils/ksettings/dispatcher.h
+++ b/kutils/ksettings/dispatcher.h
@@ -65,7 +65,7 @@ class KUTILS_EXPORT Dispatcher : public TQObject
* that is passed to KGenericFactory (if it is used). You can query
* it with KGenericFactory<YourClassName>::instance().
* instance->instanceName() is also the same name that is put into the
- * .desktop file of the KCMs for the X-KDE-ParentComponents.
+ * .desktop file of the KCMs for the X-TDE-ParentComponents.
*
* @param instance The KInstance object
* @param recv The object that should receive the signal
@@ -95,7 +95,7 @@ class KUTILS_EXPORT Dispatcher : public TQObject
* Call this slot when the configuration belonging to the associated
* instance name has changed. The registered slot will be called.
*
- * @param instanceName The value of X-KDE-ParentComponents.
+ * @param instanceName The value of X-TDE-ParentComponents.
*/
void reparseConfiguration( const TQCString & instanceName );
diff --git a/kutils/ksettings/pluginpage.h b/kutils/ksettings/pluginpage.h
index 6f6fdda83..df9acd490 100644
--- a/kutils/ksettings/pluginpage.h
+++ b/kutils/ksettings/pluginpage.h
@@ -57,11 +57,11 @@ namespace KSettings
Type=Service
ServiceTypes=KCModule
- X-KDE-ModuleType=Library
- X-KDE-Library=myapppluginconfig
- X-KDE-FactoryName=MyAppPluginConfigFactory
- X-KDE-ParentApp=myapp
- X-KDE-ParentComponents=myapp
+ X-TDE-ModuleType=Library
+ X-TDE-Library=myapppluginconfig
+ X-TDE-FactoryName=MyAppPluginConfigFactory
+ X-TDE-ParentApp=myapp
+ X-TDE-ParentComponents=myapp
Name=Plugins
Comment=Select and configure your plugins:
diff --git a/kutils/kplugininfo.h b/kutils/kplugininfo.h
index 59aa75983..b75edf1a2 100644
--- a/kutils/kplugininfo.h
+++ b/kutils/kplugininfo.h
@@ -53,7 +53,7 @@ class KUTILS_EXPORT KPluginInfo
Name=User Visible Name
Comment=Description of what the plugin does
- [X-KDE Plugin Info]
+ [X-TDE Plugin Info]
Author=Author's Name
Email=author@foo.bar
PluginName=internalname
@@ -67,7 +67,7 @@ class KUTILS_EXPORT KPluginInfo
* The first two entries in the "Desktop Entry" group always need to
* be present.
*
* The "X-KDE-PluginInfo" keys you may add further entries which
* will be available using property(). The Website,Category,Require
* keys are optional.
* For EnabledByDefault look at isPluginEnabledByDefault.
@@ -90,15 +90,15 @@ class KUTILS_EXPORT KPluginInfo
Type=Service
ServiceTypes=KPluginInfo
- X-KDE-PluginInfo-Author=Author's Name
- X-KDE-PluginInfo-Email=author@foo.bar
- X-KDE-PluginInfo-Name=internalname
- X-KDE-PluginInfo-Version=1.1
- X-KDE-PluginInfo-Website=http://www.plugin.org/
- X-KDE-PluginInfo-Category=playlist
- X-KDE-PluginInfo-Depends=plugin1,plugin3
- X-KDE-PluginInfo-License=GPL
- X-KDE-PluginInfo-EnabledByDefault=true
+ X-TDE-PluginInfo-Author=Author's Name
+ X-TDE-PluginInfo-Email=author@foo.bar
+ X-TDE-PluginInfo-Name=internalname
+ X-TDE-PluginInfo-Version=1.1
+ X-TDE-PluginInfo-Website=http://www.plugin.org/
+ X-TDE-PluginInfo-Category=playlist
+ X-TDE-PluginInfo-Depends=plugin1,plugin3
+ X-TDE-PluginInfo-License=GPL
+ X-TDE-PluginInfo-EnabledByDefault=true
Name=User Visible Name
Comment=Description of what the plugin does
@@ -67,7 +67,7 @@ class KUTILS_EXPORT KPluginInfo
* be present.
*
- * The "X-KDE-PluginInfo" keys you may add further entries which
+ * The "X-TDE-PluginInfo" keys you may add further entries which
* will be available using property(). The Website,Category,Require
* keys are optional.